# -*- coding: utf-8 -*-
"""日志消息处理__init__.py 模块

本日志功能拷贝并修改自 万花（我的世界指令IDE）

引用协议：
版权所有© 全体 万花 作者

   Copyright 2022 all the developers of Kaleido

   Licensed under the Apache License, Version 2.0 (the 'License');
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       https://www.apache.org/licenses/LICENSE-2.0
继承协议：
版权所有© 全体 万花项目 和 睿穆组织 作者

   Copyright 2022-2023 all the developers of Kaleido and Trim Organization

   Licensed under the Apache License, Version 2.0 (the 'License');
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       https://www.apache.org/licenses/LICENSE-2.0
"""

from .logger_main import *

__version__: str = "v0.7.3"

set_version(__version__)


def get_version() -> str:
    """获取版本号"""
    return __version__


__all__ = [
    "logger",
    "osc_",
    "pip_manage_",
    "DEBUG",
    "INFO",
    "WARNING",
    "ERROR",
    "CRITICAL",
    "ObjectStateConstant",
    "PipManage",
    "py_version",
    "get_version",
    "log__init__",
]
